# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/api/api.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from iotexetl.rpc.iotextypes import action_pb2 as proto_dot_types_dot_action__pb2
from iotexetl.rpc.iotextypes import blockchain_pb2 as proto_dot_types_dot_blockchain__pb2
from iotexetl.rpc.iotextypes import node_pb2 as proto_dot_types_dot_node__pb2
from iotexetl.rpc.iotextypes import election_pb2 as proto_dot_types_dot_election__pb2
from iotexetl.rpc.iotextypes import transaction_log_pb2 as proto_dot_types_dot_transaction__log__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/api/api.proto',
  package='iotexapi',
  syntax='proto3',
  serialized_options=b'\n com.github.iotexproject.grpc.apiP\001Z3github.com/iotexproject/iotex-proto/golang/iotexapi',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13proto/api/api.proto\x12\x08iotexapi\x1a\x18proto/types/action.proto\x1a\x1cproto/types/blockchain.proto\x1a\x16proto/types/node.proto\x1a\x1aproto/types/election.proto\x1a!proto/types/transaction_log.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"X\n\x06\x42ucket\x12\r\n\x05voter\x18\x01 \x01(\t\x12\r\n\x05votes\x18\x02 \x01(\t\x12\x15\n\rweightedVotes\x18\x03 \x01(\t\x12\x19\n\x11remainingDuration\x18\x04 \x01(\t\"$\n\x11GetAccountRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"x\n\x12GetAccountResponse\x12,\n\x0b\x61\x63\x63ountMeta\x18\x01 \x01(\x0b\x32\x17.iotextypes.AccountMeta\x12\x34\n\x0f\x62lockIdentifier\x18\x02 \x01(\x0b\x32\x1b.iotextypes.BlockIdentifier\"\xc3\x02\n\x11GetActionsRequest\x12\x35\n\x07\x62yIndex\x18\x01 \x01(\x0b\x32\".iotexapi.GetActionsByIndexRequestH\x00\x12\x32\n\x06\x62yHash\x18\x02 \x01(\x0b\x32 .iotexapi.GetActionByHashRequestH\x00\x12\x36\n\x06\x62yAddr\x18\x03 \x01(\x0b\x32$.iotexapi.GetActionsByAddressRequestH\x00\x12L\n\x11unconfirmedByAddr\x18\x04 \x01(\x0b\x32/.iotexapi.GetUnconfirmedActionsByAddressRequestH\x00\x12\x33\n\x05\x62yBlk\x18\x05 \x01(\x0b\x32\".iotexapi.GetActionsByBlockRequestH\x00\x42\x08\n\x06lookup\"8\n\x18GetActionsByIndexRequest\x12\r\n\x05start\x18\x01 \x01(\x04\x12\r\n\x05\x63ount\x18\x02 \x01(\x04\"B\n\x16GetActionByHashRequest\x12\x12\n\nactionHash\x18\x01 \x01(\t\x12\x14\n\x0c\x63heckPending\x18\x02 \x01(\x08\"K\n\x1aGetActionsByAddressRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\r\n\x05start\x18\x02 \x01(\x04\x12\r\n\x05\x63ount\x18\x03 \x01(\x04\"V\n%GetUnconfirmedActionsByAddressRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\r\n\x05start\x18\x02 \x01(\x04\x12\r\n\x05\x63ount\x18\x03 \x01(\x04\"I\n\x18GetActionsByBlockRequest\x12\x0f\n\x07\x62lkHash\x18\x01 \x01(\t\x12\r\n\x05start\x18\x02 \x01(\x04\x12\r\n\x05\x63ount\x18\x03 \x01(\x04\"\xb4\x01\n\nActionInfo\x12\"\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32\x12.iotextypes.Action\x12\x0f\n\x07\x61\x63tHash\x18\x02 \x01(\t\x12\x0f\n\x07\x62lkHash\x18\x03 \x01(\t\x12\x11\n\tblkHeight\x18\x05 \x01(\x04\x12\x0e\n\x06sender\x18\x06 \x01(\t\x12\x0e\n\x06gasFee\x18\x07 \x01(\t\x12-\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"D\n\x0bReceiptInfo\x12$\n\x07receipt\x18\x01 \x01(\x0b\x32\x13.iotextypes.Receipt\x12\x0f\n\x07\x62lkHash\x18\x02 \x01(\t\"W\n\x11\x42lockProducerInfo\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\r\n\x05votes\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x03 \x01(\x08\x12\x12\n\nproduction\x18\x04 \x01(\x04\"T\n\tBlockInfo\x12 \n\x05\x62lock\x18\x01 \x01(\x0b\x32\x11.iotextypes.Block\x12%\n\x08receipts\x18\x02 \x03(\x0b\x32\x13.iotextypes.Receipt\"M\n\x12GetActionsResponse\x12\r\n\x05total\x18\x02 \x01(\x04\x12(\n\nactionInfo\x18\x01 \x03(\x0b\x32\x14.iotexapi.ActionInfo\"\x91\x01\n\x14GetBlockMetasRequest\x12\x38\n\x07\x62yIndex\x18\x01 \x01(\x0b\x32%.iotexapi.GetBlockMetasByIndexRequestH\x00\x12\x35\n\x06\x62yHash\x18\x02 \x01(\x0b\x32#.iotexapi.GetBlockMetaByHashRequestH\x00\x42\x08\n\x06lookup\";\n\x1bGetBlockMetasByIndexRequest\x12\r\n\x05start\x18\x01 \x01(\x04\x12\r\n\x05\x63ount\x18\x02 \x01(\x04\",\n\x19GetBlockMetaByHashRequest\x12\x0f\n\x07\x62lkHash\x18\x01 \x01(\t\"O\n\x15GetBlockMetasResponse\x12\r\n\x05total\x18\x02 \x01(\x04\x12\'\n\x08\x62lkMetas\x18\x01 \x03(\x0b\x32\x15.iotextypes.BlockMeta\"\x15\n\x13GetChainMetaRequest\"@\n\x14GetChainMetaResponse\x12(\n\tchainMeta\x18\x01 \x01(\x0b\x32\x15.iotextypes.ChainMeta\"\x16\n\x14GetServerMetaRequest\"C\n\x15GetServerMetaResponse\x12*\n\nserverMeta\x18\x01 \x01(\x0b\x32\x16.iotextypes.ServerMeta\"7\n\x11SendActionRequest\x12\"\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32\x12.iotextypes.Action\"9\n\x1cSendSignedActionBytesRequest\x12\x19\n\x11signedActionBytes\x18\x01 \x01(\t\"(\n\x12SendActionResponse\x12\x12\n\nactionHash\x18\x01 \x01(\t\"/\n\x19GetReceiptByActionRequest\x12\x12\n\nactionHash\x18\x01 \x01(\t\"H\n\x1aGetReceiptByActionResponse\x12*\n\x0breceiptInfo\x18\x01 \x01(\x0b\x32\x15.iotexapi.ReceiptInfo\"V\n\x13ReadContractRequest\x12(\n\texecution\x18\x01 \x01(\x0b\x32\x15.iotextypes.Execution\x12\x15\n\rcallerAddress\x18\x02 \x01(\t\"J\n\x14ReadContractResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\x12$\n\x07receipt\x18\x02 \x01(\x0b\x32\x13.iotextypes.Receipt\"\x18\n\x16SuggestGasPriceRequest\"+\n\x17SuggestGasPriceResponse\x12\x10\n\x08gasPrice\x18\x01 \x01(\x04\"A\n\x1b\x45stimateGasForActionRequest\x12\"\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32\x12.iotextypes.Action\"\x9a\x05\n#EstimateActionGasConsumptionRequest\x12(\n\x08transfer\x18\x01 \x01(\x0b\x32\x14.iotextypes.TransferH\x00\x12*\n\texecution\x18\x02 \x01(\x0b\x32\x15.iotextypes.ExecutionH\x00\x12.\n\x0bstakeCreate\x18( \x01(\x0b\x32\x17.iotextypes.StakeCreateH\x00\x12\x30\n\x0cstakeUnstake\x18) \x01(\x0b\x32\x18.iotextypes.StakeReclaimH\x00\x12\x31\n\rstakeWithdraw\x18* \x01(\x0b\x32\x18.iotextypes.StakeReclaimH\x00\x12\x36\n\x0fstakeAddDeposit\x18+ \x01(\x0b\x32\x1b.iotextypes.StakeAddDepositH\x00\x12\x30\n\x0cstakeRestake\x18, \x01(\x0b\x32\x18.iotextypes.StakeRestakeH\x00\x12@\n\x14stakeChangeCandidate\x18- \x01(\x0b\x32 .iotextypes.StakeChangeCandidateH\x00\x12\x44\n\x16stakeTransferOwnership\x18. \x01(\x0b\x32\".iotextypes.StakeTransferOwnershipH\x00\x12:\n\x11\x63\x61ndidateRegister\x18/ \x01(\x0b\x32\x1d.iotextypes.CandidateRegisterH\x00\x12\x39\n\x0f\x63\x61ndidateUpdate\x18\x30 \x01(\x0b\x32\x1e.iotextypes.CandidateBasicInfoH\x00\x12\x15\n\rcallerAddress\x18\x64 \x01(\tB\x08\n\x06\x61\x63tion\"3\n$EstimateActionGasConsumptionResponse\x12\x0b\n\x03gas\x18\x01 \x01(\x04\"+\n\x1c\x45stimateGasForActionResponse\x12\x0b\n\x03gas\x18\x01 \x01(\x04\"]\n\x10ReadStateRequest\x12\x12\n\nprotocolID\x18\x01 \x01(\x0c\x12\x12\n\nmethodName\x18\x02 \x01(\x0c\x12\x11\n\targuments\x18\x03 \x03(\x0c\x12\x0e\n\x06height\x18\x04 \x01(\t\"W\n\x11ReadStateResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x34\n\x0f\x62lockIdentifier\x18\x02 \x01(\x0b\x32\x1b.iotextypes.BlockIdentifier\"*\n\x13GetEpochMetaRequest\x12\x13\n\x0b\x65pochNumber\x18\x01 \x01(\x04\"\x8e\x01\n\x14GetEpochMetaResponse\x12(\n\tepochData\x18\x01 \x01(\x0b\x32\x15.iotextypes.EpochData\x12\x13\n\x0btotalBlocks\x18\x02 \x01(\x04\x12\x37\n\x12\x62lockProducersInfo\x18\x03 \x03(\x0b\x32\x1b.iotexapi.BlockProducerInfo\"O\n\x13GetRawBlocksRequest\x12\x13\n\x0bstartHeight\x18\x01 \x01(\x04\x12\r\n\x05\x63ount\x18\x02 \x01(\x04\x12\x14\n\x0cwithReceipts\x18\x03 \x01(\x08\";\n\x14GetRawBlocksResponse\x12#\n\x06\x62locks\x18\x01 \x03(\x0b\x32\x13.iotexapi.BlockInfo\"#\n\x0eGetLogsByBlock\x12\x11\n\tblockHash\x18\x01 \x01(\x0c\"2\n\x0eGetLogsByRange\x12\x11\n\tfromBlock\x18\x01 \x01(\x04\x12\r\n\x05\x63ount\x18\x02 \x01(\x04\"\x17\n\x06Topics\x12\r\n\x05topic\x18\x01 \x03(\x0c\"?\n\nLogsFilter\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x03(\t\x12 \n\x06topics\x18\x02 \x03(\x0b\x32\x10.iotexapi.Topics\"\x9a\x01\n\x0eGetLogsRequest\x12$\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x14.iotexapi.LogsFilter\x12+\n\x07\x62yBlock\x18\x02 \x01(\x0b\x32\x18.iotexapi.GetLogsByBlockH\x00\x12+\n\x07\x62yRange\x18\x03 \x01(\x0b\x32\x18.iotexapi.GetLogsByRangeH\x00\x42\x08\n\x06lookup\"0\n\x0fGetLogsResponse\x12\x1d\n\x04logs\x18\x01 \x03(\x0b\x32\x0f.iotextypes.Log\"8\n\"GetEvmTransfersByActionHashRequest\x12\x12\n\nactionHash\x18\x01 \x01(\t\"`\n#GetEvmTransfersByActionHashResponse\x12\x39\n\x12\x61\x63tionEvmTransfers\x18\x01 \x01(\x0b\x32\x1d.iotextypes.ActionEvmTransfer\":\n#GetEvmTransfersByBlockHeightRequest\x12\x13\n\x0b\x62lockHeight\x18\x01 \x01(\x04\"_\n$GetEvmTransfersByBlockHeightResponse\x12\x37\n\x11\x62lockEvmTransfers\x18\x01 \x01(\x0b\x32\x1c.iotextypes.BlockEvmTransfer\":\n$GetTransactionLogByActionHashRequest\x12\x12\n\nactionHash\x18\x01 \x01(\t\"[\n%GetTransactionLogByActionHashResponse\x12\x32\n\x0etransactionLog\x18\x01 \x01(\x0b\x32\x1a.iotextypes.TransactionLog\"<\n%GetTransactionLogByBlockHeightRequest\x12\x13\n\x0b\x62lockHeight\x18\x01 \x01(\x04\"\x94\x01\n&GetTransactionLogByBlockHeightResponse\x12\x34\n\x0ftransactionLogs\x18\x01 \x01(\x0b\x32\x1b.iotextypes.TransactionLogs\x12\x34\n\x0f\x62lockIdentifier\x18\x02 \x01(\x0b\x32\x1b.iotextypes.BlockIdentifier\"\x15\n\x13StreamBlocksRequest\":\n\x14StreamBlocksResponse\x12\"\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x13.iotexapi.BlockInfo\"9\n\x11StreamLogsRequest\x12$\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x14.iotexapi.LogsFilter\"2\n\x12StreamLogsResponse\x12\x1c\n\x03log\x18\x01 \x01(\x0b\x32\x0f.iotextypes.Log\"-\n\x19GetElectionBucketsRequest\x12\x10\n\x08\x65pochNum\x18\x01 \x01(\x04\"I\n\x1aGetElectionBucketsResponse\x12+\n\x07\x62uckets\x18\x01 \x03(\x0b\x32\x1a.iotextypes.ElectionBucket2\x99\x10\n\nAPIService\x12I\n\nGetAccount\x12\x1b.iotexapi.GetAccountRequest\x1a\x1c.iotexapi.GetAccountResponse\"\x00\x12I\n\nGetActions\x12\x1b.iotexapi.GetActionsRequest\x1a\x1c.iotexapi.GetActionsResponse\"\x00\x12R\n\rGetBlockMetas\x12\x1e.iotexapi.GetBlockMetasRequest\x1a\x1f.iotexapi.GetBlockMetasResponse\"\x00\x12O\n\x0cGetChainMeta\x12\x1d.iotexapi.GetChainMetaRequest\x1a\x1e.iotexapi.GetChainMetaResponse\"\x00\x12R\n\rGetServerMeta\x12\x1e.iotexapi.GetServerMetaRequest\x1a\x1f.iotexapi.GetServerMetaResponse\"\x00\x12I\n\nSendAction\x12\x1b.iotexapi.SendActionRequest\x1a\x1c.iotexapi.SendActionResponse\"\x00\x12\x61\n\x12GetReceiptByAction\x12#.iotexapi.GetReceiptByActionRequest\x1a$.iotexapi.GetReceiptByActionResponse\"\x00\x12O\n\x0cReadContract\x12\x1d.iotexapi.ReadContractRequest\x1a\x1e.iotexapi.ReadContractResponse\"\x00\x12X\n\x0fSuggestGasPrice\x12 .iotexapi.SuggestGasPriceRequest\x1a!.iotexapi.SuggestGasPriceResponse\"\x00\x12g\n\x14\x45stimateGasForAction\x12%.iotexapi.EstimateGasForActionRequest\x1a&.iotexapi.EstimateGasForActionResponse\"\x00\x12\x7f\n\x1c\x45stimateActionGasConsumption\x12-.iotexapi.EstimateActionGasConsumptionRequest\x1a..iotexapi.EstimateActionGasConsumptionResponse\"\x00\x12\x46\n\tReadState\x12\x1a.iotexapi.ReadStateRequest\x1a\x1b.iotexapi.ReadStateResponse\"\x00\x12O\n\x0cGetEpochMeta\x12\x1d.iotexapi.GetEpochMetaRequest\x1a\x1e.iotexapi.GetEpochMetaResponse\"\x00\x12O\n\x0cGetRawBlocks\x12\x1d.iotexapi.GetRawBlocksRequest\x1a\x1e.iotexapi.GetRawBlocksResponse\"\x00\x12@\n\x07GetLogs\x12\x18.iotexapi.GetLogsRequest\x1a\x19.iotexapi.GetLogsResponse\"\x00\x12|\n\x1bGetEvmTransfersByActionHash\x12,.iotexapi.GetEvmTransfersByActionHashRequest\x1a-.iotexapi.GetEvmTransfersByActionHashResponse\"\x00\x12\x7f\n\x1cGetEvmTransfersByBlockHeight\x12-.iotexapi.GetEvmTransfersByBlockHeightRequest\x1a..iotexapi.GetEvmTransfersByBlockHeightResponse\"\x00\x12\x82\x01\n\x1dGetTransactionLogByActionHash\x12..iotexapi.GetTransactionLogByActionHashRequest\x1a/.iotexapi.GetTransactionLogByActionHashResponse\"\x00\x12\x85\x01\n\x1eGetTransactionLogByBlockHeight\x12/.iotexapi.GetTransactionLogByBlockHeightRequest\x1a\x30.iotexapi.GetTransactionLogByBlockHeightResponse\"\x00\x12Q\n\x0cStreamBlocks\x12\x1d.iotexapi.StreamBlocksRequest\x1a\x1e.iotexapi.StreamBlocksResponse\"\x00\x30\x01\x12K\n\nStreamLogs\x12\x1b.iotexapi.StreamLogsRequest\x1a\x1c.iotexapi.StreamLogsResponse\"\x00\x30\x01\x12\x61\n\x12GetElectionBuckets\x12#.iotexapi.GetElectionBucketsRequest\x1a$.iotexapi.GetElectionBucketsResponse\"\x00\x32\xa4\x02\n\x15TransactionLogService\x12\x82\x01\n\x1dGetTransactionLogByActionHash\x12..iotexapi.GetTransactionLogByActionHashRequest\x1a/.iotexapi.GetTransactionLogByActionHashResponse\"\x00\x12\x85\x01\n\x1eGetTransactionLogByBlockHeight\x12/.iotexapi.GetTransactionLogByBlockHeightRequest\x1a\x30.iotexapi.GetTransactionLogByBlockHeightResponse\"\x00\x42Y\n com.github.iotexproject.grpc.apiP\x01Z3github.com/iotexproject/iotex-proto/golang/iotexapib\x06proto3'
  ,
  dependencies=[proto_dot_types_dot_action__pb2.DESCRIPTOR,proto_dot_types_dot_blockchain__pb2.DESCRIPTOR,proto_dot_types_dot_node__pb2.DESCRIPTOR,proto_dot_types_dot_election__pb2.DESCRIPTOR,proto_dot_types_dot_transaction__log__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_BUCKET = _descriptor.Descriptor(
  name='Bucket',
  full_name='iotexapi.Bucket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='voter', full_name='iotexapi.Bucket.voter', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='votes', full_name='iotexapi.Bucket.votes', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weightedVotes', full_name='iotexapi.Bucket.weightedVotes', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remainingDuration', full_name='iotexapi.Bucket.remainingDuration', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=297,
)


_GETACCOUNTREQUEST = _descriptor.Descriptor(
  name='GetAccountRequest',
  full_name='iotexapi.GetAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='iotexapi.GetAccountRequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=335,
)


_GETACCOUNTRESPONSE = _descriptor.Descriptor(
  name='GetAccountResponse',
  full_name='iotexapi.GetAccountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountMeta', full_name='iotexapi.GetAccountResponse.accountMeta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blockIdentifier', full_name='iotexapi.GetAccountResponse.blockIdentifier', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=337,
  serialized_end=457,
)


_GETACTIONSREQUEST = _descriptor.Descriptor(
  name='GetActionsRequest',
  full_name='iotexapi.GetActionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='byIndex', full_name='iotexapi.GetActionsRequest.byIndex', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='byHash', full_name='iotexapi.GetActionsRequest.byHash', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='byAddr', full_name='iotexapi.GetActionsRequest.byAddr', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unconfirmedByAddr', full_name='iotexapi.GetActionsRequest.unconfirmedByAddr', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='byBlk', full_name='iotexapi.GetActionsRequest.byBlk', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='lookup', full_name='iotexapi.GetActionsRequest.lookup',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=460,
  serialized_end=783,
)


_GETACTIONSBYINDEXREQUEST = _descriptor.Descriptor(
  name='GetActionsByIndexRequest',
  full_name='iotexapi.GetActionsByIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='iotexapi.GetActionsByIndexRequest.start', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='iotexapi.GetActionsByIndexRequest.count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=785,
  serialized_end=841,
)


_GETACTIONBYHASHREQUEST = _descriptor.Descriptor(
  name='GetActionByHashRequest',
  full_name='iotexapi.GetActionByHashRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actionHash', full_name='iotexapi.GetActionByHashRequest.actionHash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checkPending', full_name='iotexapi.GetActionByHashRequest.checkPending', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=843,
  serialized_end=909,
)


_GETACTIONSBYADDRESSREQUEST = _descriptor.Descriptor(
  name='GetActionsByAddressRequest',
  full_name='iotexapi.GetActionsByAddressRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='iotexapi.GetActionsByAddressRequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='iotexapi.GetActionsByAddressRequest.start', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='iotexapi.GetActionsByAddressRequest.count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=911,
  serialized_end=986,
)


_GETUNCONFIRMEDACTIONSBYADDRESSREQUEST = _descriptor.Descriptor(
  name='GetUnconfirmedActionsByAddressRequest',
  full_name='iotexapi.GetUnconfirmedActionsByAddressRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='iotexapi.GetUnconfirmedActionsByAddressRequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='iotexapi.GetUnconfirmedActionsByAddressRequest.start', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='iotexapi.GetUnconfirmedActionsByAddressRequest.count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=988,
  serialized_end=1074,
)


_GETACTIONSBYBLOCKREQUEST = _descriptor.Descriptor(
  name='GetActionsByBlockRequest',
  full_name='iotexapi.GetActionsByBlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='blkHash', full_name='iotexapi.GetActionsByBlockRequest.blkHash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='iotexapi.GetActionsByBlockRequest.start', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='iotexapi.GetActionsByBlockRequest.count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1076,
  serialized_end=1149,
)


_ACTIONINFO = _descriptor.Descriptor(
  name='ActionInfo',
  full_name='iotexapi.ActionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='iotexapi.ActionInfo.action', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actHash', full_name='iotexapi.ActionInfo.actHash', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blkHash', full_name='iotexapi.ActionInfo.blkHash', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blkHeight', full_name='iotexapi.ActionInfo.blkHeight', index=3,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender', full_name='iotexapi.ActionInfo.sender', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gasFee', full_name='iotexapi.ActionInfo.gasFee', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='iotexapi.ActionInfo.timestamp', index=6,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1152,
  serialized_end=1332,
)


_RECEIPTINFO = _descriptor.Descriptor(
  name='ReceiptInfo',
  full_name='iotexapi.ReceiptInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='receipt', full_name='iotexapi.ReceiptInfo.receipt', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blkHash', full_name='iotexapi.ReceiptInfo.blkHash', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1334,
  serialized_end=1402,
)


_BLOCKPRODUCERINFO = _descriptor.Descriptor(
  name='BlockProducerInfo',
  full_name='iotexapi.BlockProducerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='iotexapi.BlockProducerInfo.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='votes', full_name='iotexapi.BlockProducerInfo.votes', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='iotexapi.BlockProducerInfo.active', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='production', full_name='iotexapi.BlockProducerInfo.production', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1404,
  serialized_end=1491,
)


_BLOCKINFO = _descriptor.Descriptor(
  name='BlockInfo',
  full_name='iotexapi.BlockInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='iotexapi.BlockInfo.block', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receipts', full_name='iotexapi.BlockInfo.receipts', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1493,
  serialized_end=1577,
)


_GETACTIONSRESPONSE = _descriptor.Descriptor(
  name='GetActionsResponse',
  full_name='iotexapi.GetActionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='iotexapi.GetActionsResponse.total', index=0,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actionInfo', full_name='iotexapi.GetActionsResponse.actionInfo', index=1,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1579,
  serialized_end=1656,
)


_GETBLOCKMETASREQUEST = _descriptor.Descriptor(
  name='GetBlockMetasRequest',
  full_name='iotexapi.GetBlockMetasRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='byIndex', full_name='iotexapi.GetBlockMetasRequest.byIndex', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='byHash', full_name='iotexapi.GetBlockMetasRequest.byHash', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='lookup', full_name='iotexapi.GetBlockMetasRequest.lookup',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1659,
  serialized_end=1804,
)


_GETBLOCKMETASBYINDEXREQUEST = _descriptor.Descriptor(
  name='GetBlockMetasByIndexRequest',
  full_name='iotexapi.GetBlockMetasByIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='iotexapi.GetBlockMetasByIndexRequest.start', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='iotexapi.GetBlockMetasByIndexRequest.count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1806,
  serialized_end=1865,
)


_GETBLOCKMETABYHASHREQUEST = _descriptor.Descriptor(
  name='GetBlockMetaByHashRequest',
  full_name='iotexapi.GetBlockMetaByHashRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='blkHash', full_name='iotexapi.GetBlockMetaByHashRequest.blkHash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1867,
  serialized_end=1911,
)


_GETBLOCKMETASRESPONSE = _descriptor.Descriptor(
  name='GetBlockMetasResponse',
  full_name='iotexapi.GetBlockMetasResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='iotexapi.GetBlockMetasResponse.total', index=0,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blkMetas', full_name='iotexapi.GetBlockMetasResponse.blkMetas', index=1,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1913,
  serialized_end=1992,
)


_GETCHAINMETAREQUEST = _descriptor.Descriptor(
  name='GetChainMetaRequest',
  full_name='iotexapi.GetChainMetaRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1994,
  serialized_end=2015,
)


_GETCHAINMETARESPONSE = _descriptor.Descriptor(
  name='GetChainMetaResponse',
  full_name='iotexapi.GetChainMetaResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chainMeta', full_name='iotexapi.GetChainMetaResponse.chainMeta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2017,
  serialized_end=2081,
)


_GETSERVERMETAREQUEST = _descriptor.Descriptor(
  name='GetServerMetaRequest',
  full_name='iotexapi.GetServerMetaRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2083,
  serialized_end=2105,
)


_GETSERVERMETARESPONSE = _descriptor.Descriptor(
  name='GetServerMetaResponse',
  full_name='iotexapi.GetServerMetaResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serverMeta', full_name='iotexapi.GetServerMetaResponse.serverMeta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2107,
  serialized_end=2174,
)


_SENDACTIONREQUEST = _descriptor.Descriptor(
  name='SendActionRequest',
  full_name='iotexapi.SendActionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='iotexapi.SendActionRequest.action', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2176,
  serialized_end=2231,
)


_SENDSIGNEDACTIONBYTESREQUEST = _descriptor.Descriptor(
  name='SendSignedActionBytesRequest',
  full_name='iotexapi.SendSignedActionBytesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signedActionBytes', full_name='iotexapi.SendSignedActionBytesRequest.signedActionBytes', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2233,
  serialized_end=2290,
)


_SENDACTIONRESPONSE = _descriptor.Descriptor(
  name='SendActionResponse',
  full_name='iotexapi.SendActionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actionHash', full_name='iotexapi.SendActionResponse.actionHash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2292,
  serialized_end=2332,
)


_GETRECEIPTBYACTIONREQUEST = _descriptor.Descriptor(
  name='GetReceiptByActionRequest',
  full_name='iotexapi.GetReceiptByActionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actionHash', full_name='iotexapi.GetReceiptByActionRequest.actionHash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2334,
  serialized_end=2381,
)


_GETRECEIPTBYACTIONRESPONSE = _descriptor.Descriptor(
  name='GetReceiptByActionResponse',
  full_name='iotexapi.GetReceiptByActionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='receiptInfo', full_name='iotexapi.GetReceiptByActionResponse.receiptInfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2383,
  serialized_end=2455,
)


_READCONTRACTREQUEST = _descriptor.Descriptor(
  name='ReadContractRequest',
  full_name='iotexapi.ReadContractRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='execution', full_name='iotexapi.ReadContractRequest.execution', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='callerAddress', full_name='iotexapi.ReadContractRequest.callerAddress', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2457,
  serialized_end=2543,
)


_READCONTRACTRESPONSE = _descriptor.Descriptor(
  name='ReadContractResponse',
  full_name='iotexapi.ReadContractResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='iotexapi.ReadContractResponse.data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receipt', full_name='iotexapi.ReadContractResponse.receipt', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2545,
  serialized_end=2619,
)


_SUGGESTGASPRICEREQUEST = _descriptor.Descriptor(
  name='SuggestGasPriceRequest',
  full_name='iotexapi.SuggestGasPriceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2621,
  serialized_end=2645,
)


_SUGGESTGASPRICERESPONSE = _descriptor.Descriptor(
  name='SuggestGasPriceResponse',
  full_name='iotexapi.SuggestGasPriceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gasPrice', full_name='iotexapi.SuggestGasPriceResponse.gasPrice', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2647,
  serialized_end=2690,
)


_ESTIMATEGASFORACTIONREQUEST = _descriptor.Descriptor(
  name='EstimateGasForActionRequest',
  full_name='iotexapi.EstimateGasForActionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='iotexapi.EstimateGasForActionRequest.action', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2692,
  serialized_end=2757,
)


_ESTIMATEACTIONGASCONSUMPTIONREQUEST = _descriptor.Descriptor(
  name='EstimateActionGasConsumptionRequest',
  full_name='iotexapi.EstimateActionGasConsumptionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transfer', full_name='iotexapi.EstimateActionGasConsumptionRequest.transfer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution', full_name='iotexapi.EstimateActionGasConsumptionRequest.execution', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stakeCreate', full_name='iotexapi.EstimateActionGasConsumptionRequest.stakeCreate', index=2,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stakeUnstake', full_name='iotexapi.EstimateActionGasConsumptionRequest.stakeUnstake', index=3,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stakeWithdraw', full_name='iotexapi.EstimateActionGasConsumptionRequest.stakeWithdraw', index=4,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stakeAddDeposit', full_name='iotexapi.EstimateActionGasConsumptionRequest.stakeAddDeposit', index=5,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stakeRestake', full_name='iotexapi.EstimateActionGasConsumptionRequest.stakeRestake', index=6,
      number=44, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stakeChangeCandidate', full_name='iotexapi.EstimateActionGasConsumptionRequest.stakeChangeCandidate', index=7,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stakeTransferOwnership', full_name='iotexapi.EstimateActionGasConsumptionRequest.stakeTransferOwnership', index=8,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='candidateRegister', full_name='iotexapi.EstimateActionGasConsumptionRequest.candidateRegister', index=9,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='candidateUpdate', full_name='iotexapi.EstimateActionGasConsumptionRequest.candidateUpdate', index=10,
      number=48, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='callerAddress', full_name='iotexapi.EstimateActionGasConsumptionRequest.callerAddress', index=11,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='iotexapi.EstimateActionGasConsumptionRequest.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2760,
  serialized_end=3426,
)


_ESTIMATEACTIONGASCONSUMPTIONRESPONSE = _descriptor.Descriptor(
  name='EstimateActionGasConsumptionResponse',
  full_name='iotexapi.EstimateActionGasConsumptionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gas', full_name='iotexapi.EstimateActionGasConsumptionResponse.gas', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3428,
  serialized_end=3479,
)


_ESTIMATEGASFORACTIONRESPONSE = _descriptor.Descriptor(
  name='EstimateGasForActionResponse',
  full_name='iotexapi.EstimateGasForActionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gas', full_name='iotexapi.EstimateGasForActionResponse.gas', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3481,
  serialized_end=3524,
)


_READSTATEREQUEST = _descriptor.Descriptor(
  name='ReadStateRequest',
  full_name='iotexapi.ReadStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocolID', full_name='iotexapi.ReadStateRequest.protocolID', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='methodName', full_name='iotexapi.ReadStateRequest.methodName', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='iotexapi.ReadStateRequest.arguments', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='iotexapi.ReadStateRequest.height', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3526,
  serialized_end=3619,
)


_READSTATERESPONSE = _descriptor.Descriptor(
  name='ReadStateResponse',
  full_name='iotexapi.ReadStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='iotexapi.ReadStateResponse.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blockIdentifier', full_name='iotexapi.ReadStateResponse.blockIdentifier', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3621,
  serialized_end=3708,
)


_GETEPOCHMETAREQUEST = _descriptor.Descriptor(
  name='GetEpochMetaRequest',
  full_name='iotexapi.GetEpochMetaRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='epochNumber', full_name='iotexapi.GetEpochMetaRequest.epochNumber', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3710,
  serialized_end=3752,
)


_GETEPOCHMETARESPONSE = _descriptor.Descriptor(
  name='GetEpochMetaResponse',
  full_name='iotexapi.GetEpochMetaResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='epochData', full_name='iotexapi.GetEpochMetaResponse.epochData', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalBlocks', full_name='iotexapi.GetEpochMetaResponse.totalBlocks', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blockProducersInfo', full_name='iotexapi.GetEpochMetaResponse.blockProducersInfo', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3755,
  serialized_end=3897,
)


_GETRAWBLOCKSREQUEST = _descriptor.Descriptor(
  name='GetRawBlocksRequest',
  full_name='iotexapi.GetRawBlocksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='startHeight', full_name='iotexapi.GetRawBlocksRequest.startHeight', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='iotexapi.GetRawBlocksRequest.count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='withReceipts', full_name='iotexapi.GetRawBlocksRequest.withReceipts', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3899,
  serialized_end=3978,
)


_GETRAWBLOCKSRESPONSE = _descriptor.Descriptor(
  name='GetRawBlocksResponse',
  full_name='iotexapi.GetRawBlocksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='blocks', full_name='iotexapi.GetRawBlocksResponse.blocks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3980,
  serialized_end=4039,
)


_GETLOGSBYBLOCK = _descriptor.Descriptor(
  name='GetLogsByBlock',
  full_name='iotexapi.GetLogsByBlock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockHash', full_name='iotexapi.GetLogsByBlock.blockHash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4041,
  serialized_end=4076,
)


_GETLOGSBYRANGE = _descriptor.Descriptor(
  name='GetLogsByRange',
  full_name='iotexapi.GetLogsByRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fromBlock', full_name='iotexapi.GetLogsByRange.fromBlock', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='iotexapi.GetLogsByRange.count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4078,
  serialized_end=4128,
)


_TOPICS = _descriptor.Descriptor(
  name='Topics',
  full_name='iotexapi.Topics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic', full_name='iotexapi.Topics.topic', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4130,
  serialized_end=4153,
)


_LOGSFILTER = _descriptor.Descriptor(
  name='LogsFilter',
  full_name='iotexapi.LogsFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='iotexapi.LogsFilter.address', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topics', full_name='iotexapi.LogsFilter.topics', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4155,
  serialized_end=4218,
)


_GETLOGSREQUEST = _descriptor.Descriptor(
  name='GetLogsRequest',
  full_name='iotexapi.GetLogsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='iotexapi.GetLogsRequest.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='byBlock', full_name='iotexapi.GetLogsRequest.byBlock', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='byRange', full_name='iotexapi.GetLogsRequest.byRange', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='lookup', full_name='iotexapi.GetLogsRequest.lookup',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4221,
  serialized_end=4375,
)


_GETLOGSRESPONSE = _descriptor.Descriptor(
  name='GetLogsResponse',
  full_name='iotexapi.GetLogsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='logs', full_name='iotexapi.GetLogsResponse.logs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4377,
  serialized_end=4425,
)


_GETEVMTRANSFERSBYACTIONHASHREQUEST = _descriptor.Descriptor(
  name='GetEvmTransfersByActionHashRequest',
  full_name='iotexapi.GetEvmTransfersByActionHashRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actionHash', full_name='iotexapi.GetEvmTransfersByActionHashRequest.actionHash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4427,
  serialized_end=4483,
)


_GETEVMTRANSFERSBYACTIONHASHRESPONSE = _descriptor.Descriptor(
  name='GetEvmTransfersByActionHashResponse',
  full_name='iotexapi.GetEvmTransfersByActionHashResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actionEvmTransfers', full_name='iotexapi.GetEvmTransfersByActionHashResponse.actionEvmTransfers', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4485,
  serialized_end=4581,
)


_GETEVMTRANSFERSBYBLOCKHEIGHTREQUEST = _descriptor.Descriptor(
  name='GetEvmTransfersByBlockHeightRequest',
  full_name='iotexapi.GetEvmTransfersByBlockHeightRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockHeight', full_name='iotexapi.GetEvmTransfersByBlockHeightRequest.blockHeight', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4583,
  serialized_end=4641,
)


_GETEVMTRANSFERSBYBLOCKHEIGHTRESPONSE = _descriptor.Descriptor(
  name='GetEvmTransfersByBlockHeightResponse',
  full_name='iotexapi.GetEvmTransfersByBlockHeightResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockEvmTransfers', full_name='iotexapi.GetEvmTransfersByBlockHeightResponse.blockEvmTransfers', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4643,
  serialized_end=4738,
)


_GETTRANSACTIONLOGBYACTIONHASHREQUEST = _descriptor.Descriptor(
  name='GetTransactionLogByActionHashRequest',
  full_name='iotexapi.GetTransactionLogByActionHashRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actionHash', full_name='iotexapi.GetTransactionLogByActionHashRequest.actionHash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4740,
  serialized_end=4798,
)


_GETTRANSACTIONLOGBYACTIONHASHRESPONSE = _descriptor.Descriptor(
  name='GetTransactionLogByActionHashResponse',
  full_name='iotexapi.GetTransactionLogByActionHashResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transactionLog', full_name='iotexapi.GetTransactionLogByActionHashResponse.transactionLog', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4800,
  serialized_end=4891,
)


_GETTRANSACTIONLOGBYBLOCKHEIGHTREQUEST = _descriptor.Descriptor(
  name='GetTransactionLogByBlockHeightRequest',
  full_name='iotexapi.GetTransactionLogByBlockHeightRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockHeight', full_name='iotexapi.GetTransactionLogByBlockHeightRequest.blockHeight', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4893,
  serialized_end=4953,
)


_GETTRANSACTIONLOGBYBLOCKHEIGHTRESPONSE = _descriptor.Descriptor(
  name='GetTransactionLogByBlockHeightResponse',
  full_name='iotexapi.GetTransactionLogByBlockHeightResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transactionLogs', full_name='iotexapi.GetTransactionLogByBlockHeightResponse.transactionLogs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blockIdentifier', full_name='iotexapi.GetTransactionLogByBlockHeightResponse.blockIdentifier', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4956,
  serialized_end=5104,
)


_STREAMBLOCKSREQUEST = _descriptor.Descriptor(
  name='StreamBlocksRequest',
  full_name='iotexapi.StreamBlocksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5106,
  serialized_end=5127,
)


_STREAMBLOCKSRESPONSE = _descriptor.Descriptor(
  name='StreamBlocksResponse',
  full_name='iotexapi.StreamBlocksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='iotexapi.StreamBlocksResponse.block', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5129,
  serialized_end=5187,
)


_STREAMLOGSREQUEST = _descriptor.Descriptor(
  name='StreamLogsRequest',
  full_name='iotexapi.StreamLogsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='iotexapi.StreamLogsRequest.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5189,
  serialized_end=5246,
)


_STREAMLOGSRESPONSE = _descriptor.Descriptor(
  name='StreamLogsResponse',
  full_name='iotexapi.StreamLogsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log', full_name='iotexapi.StreamLogsResponse.log', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5248,
  serialized_end=5298,
)


_GETELECTIONBUCKETSREQUEST = _descriptor.Descriptor(
  name='GetElectionBucketsRequest',
  full_name='iotexapi.GetElectionBucketsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='epochNum', full_name='iotexapi.GetElectionBucketsRequest.epochNum', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5300,
  serialized_end=5345,
)


_GETELECTIONBUCKETSRESPONSE = _descriptor.Descriptor(
  name='GetElectionBucketsResponse',
  full_name='iotexapi.GetElectionBucketsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='buckets', full_name='iotexapi.GetElectionBucketsResponse.buckets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5347,
  serialized_end=5420,
)

_GETACCOUNTRESPONSE.fields_by_name['accountMeta'].message_type = proto_dot_types_dot_blockchain__pb2._ACCOUNTMETA
_GETACCOUNTRESPONSE.fields_by_name['blockIdentifier'].message_type = proto_dot_types_dot_blockchain__pb2._BLOCKIDENTIFIER
_GETACTIONSREQUEST.fields_by_name['byIndex'].message_type = _GETACTIONSBYINDEXREQUEST
_GETACTIONSREQUEST.fields_by_name['byHash'].message_type = _GETACTIONBYHASHREQUEST
_GETACTIONSREQUEST.fields_by_name['byAddr'].message_type = _GETACTIONSBYADDRESSREQUEST
_GETACTIONSREQUEST.fields_by_name['unconfirmedByAddr'].message_type = _GETUNCONFIRMEDACTIONSBYADDRESSREQUEST
_GETACTIONSREQUEST.fields_by_name['byBlk'].message_type = _GETACTIONSBYBLOCKREQUEST
_GETACTIONSREQUEST.oneofs_by_name['lookup'].fields.append(
  _GETACTIONSREQUEST.fields_by_name['byIndex'])
_GETACTIONSREQUEST.fields_by_name['byIndex'].containing_oneof = _GETACTIONSREQUEST.oneofs_by_name['lookup']
_GETACTIONSREQUEST.oneofs_by_name['lookup'].fields.append(
  _GETACTIONSREQUEST.fields_by_name['byHash'])
_GETACTIONSREQUEST.fields_by_name['byHash'].containing_oneof = _GETACTIONSREQUEST.oneofs_by_name['lookup']
_GETACTIONSREQUEST.oneofs_by_name['lookup'].fields.append(
  _GETACTIONSREQUEST.fields_by_name['byAddr'])
_GETACTIONSREQUEST.fields_by_name['byAddr'].containing_oneof = _GETACTIONSREQUEST.oneofs_by_name['lookup']
_GETACTIONSREQUEST.oneofs_by_name['lookup'].fields.append(
  _GETACTIONSREQUEST.fields_by_name['unconfirmedByAddr'])
_GETACTIONSREQUEST.fields_by_name['unconfirmedByAddr'].containing_oneof = _GETACTIONSREQUEST.oneofs_by_name['lookup']
_GETACTIONSREQUEST.oneofs_by_name['lookup'].fields.append(
  _GETACTIONSREQUEST.fields_by_name['byBlk'])
_GETACTIONSREQUEST.fields_by_name['byBlk'].containing_oneof = _GETACTIONSREQUEST.oneofs_by_name['lookup']
_ACTIONINFO.fields_by_name['action'].message_type = proto_dot_types_dot_action__pb2._ACTION
_ACTIONINFO.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_RECEIPTINFO.fields_by_name['receipt'].message_type = proto_dot_types_dot_action__pb2._RECEIPT
_BLOCKINFO.fields_by_name['block'].message_type = proto_dot_types_dot_blockchain__pb2._BLOCK
_BLOCKINFO.fields_by_name['receipts'].message_type = proto_dot_types_dot_action__pb2._RECEIPT
_GETACTIONSRESPONSE.fields_by_name['actionInfo'].message_type = _ACTIONINFO
_GETBLOCKMETASREQUEST.fields_by_name['byIndex'].message_type = _GETBLOCKMETASBYINDEXREQUEST
_GETBLOCKMETASREQUEST.fields_by_name['byHash'].message_type = _GETBLOCKMETABYHASHREQUEST
_GETBLOCKMETASREQUEST.oneofs_by_name['lookup'].fields.append(
  _GETBLOCKMETASREQUEST.fields_by_name['byIndex'])
_GETBLOCKMETASREQUEST.fields_by_name['byIndex'].containing_oneof = _GETBLOCKMETASREQUEST.oneofs_by_name['lookup']
_GETBLOCKMETASREQUEST.oneofs_by_name['lookup'].fields.append(
  _GETBLOCKMETASREQUEST.fields_by_name['byHash'])
_GETBLOCKMETASREQUEST.fields_by_name['byHash'].containing_oneof = _GETBLOCKMETASREQUEST.oneofs_by_name['lookup']
_GETBLOCKMETASRESPONSE.fields_by_name['blkMetas'].message_type = proto_dot_types_dot_blockchain__pb2._BLOCKMETA
_GETCHAINMETARESPONSE.fields_by_name['chainMeta'].message_type = proto_dot_types_dot_blockchain__pb2._CHAINMETA
_GETSERVERMETARESPONSE.fields_by_name['serverMeta'].message_type = proto_dot_types_dot_node__pb2._SERVERMETA
_SENDACTIONREQUEST.fields_by_name['action'].message_type = proto_dot_types_dot_action__pb2._ACTION
_GETRECEIPTBYACTIONRESPONSE.fields_by_name['receiptInfo'].message_type = _RECEIPTINFO
_READCONTRACTREQUEST.fields_by_name['execution'].message_type = proto_dot_types_dot_action__pb2._EXECUTION
_READCONTRACTRESPONSE.fields_by_name['receipt'].message_type = proto_dot_types_dot_action__pb2._RECEIPT
_ESTIMATEGASFORACTIONREQUEST.fields_by_name['action'].message_type = proto_dot_types_dot_action__pb2._ACTION
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['transfer'].message_type = proto_dot_types_dot_action__pb2._TRANSFER
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['execution'].message_type = proto_dot_types_dot_action__pb2._EXECUTION
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['stakeCreate'].message_type = proto_dot_types_dot_action__pb2._STAKECREATE
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['stakeUnstake'].message_type = proto_dot_types_dot_action__pb2._STAKERECLAIM
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['stakeWithdraw'].message_type = proto_dot_types_dot_action__pb2._STAKERECLAIM
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['stakeAddDeposit'].message_type = proto_dot_types_dot_action__pb2._STAKEADDDEPOSIT
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['stakeRestake'].message_type = proto_dot_types_dot_action__pb2._STAKERESTAKE
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['stakeChangeCandidate'].message_type = proto_dot_types_dot_action__pb2._STAKECHANGECANDIDATE
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['stakeTransferOwnership'].message_type = proto_dot_types_dot_action__pb2._STAKETRANSFEROWNERSHIP
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['candidateRegister'].message_type = proto_dot_types_dot_action__pb2._CANDIDATEREGISTER
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['candidateUpdate'].message_type = proto_dot_types_dot_action__pb2._CANDIDATEBASICINFO
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.oneofs_by_name['action'].fields.append(
  _ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['transfer'])
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['transfer'].containing_oneof = _ESTIMATEACTIONGASCONSUMPTIONREQUEST.oneofs_by_name['action']
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.oneofs_by_name['action'].fields.append(
  _ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['execution'])
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['execution'].containing_oneof = _ESTIMATEACTIONGASCONSUMPTIONREQUEST.oneofs_by_name['action']
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.oneofs_by_name['action'].fields.append(
  _ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['stakeCreate'])
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['stakeCreate'].containing_oneof = _ESTIMATEACTIONGASCONSUMPTIONREQUEST.oneofs_by_name['action']
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.oneofs_by_name['action'].fields.append(
  _ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['stakeUnstake'])
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['stakeUnstake'].containing_oneof = _ESTIMATEACTIONGASCONSUMPTIONREQUEST.oneofs_by_name['action']
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.oneofs_by_name['action'].fields.append(
  _ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['stakeWithdraw'])
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['stakeWithdraw'].containing_oneof = _ESTIMATEACTIONGASCONSUMPTIONREQUEST.oneofs_by_name['action']
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.oneofs_by_name['action'].fields.append(
  _ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['stakeAddDeposit'])
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['stakeAddDeposit'].containing_oneof = _ESTIMATEACTIONGASCONSUMPTIONREQUEST.oneofs_by_name['action']
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.oneofs_by_name['action'].fields.append(
  _ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['stakeRestake'])
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['stakeRestake'].containing_oneof = _ESTIMATEACTIONGASCONSUMPTIONREQUEST.oneofs_by_name['action']
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.oneofs_by_name['action'].fields.append(
  _ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['stakeChangeCandidate'])
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['stakeChangeCandidate'].containing_oneof = _ESTIMATEACTIONGASCONSUMPTIONREQUEST.oneofs_by_name['action']
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.oneofs_by_name['action'].fields.append(
  _ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['stakeTransferOwnership'])
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['stakeTransferOwnership'].containing_oneof = _ESTIMATEACTIONGASCONSUMPTIONREQUEST.oneofs_by_name['action']
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.oneofs_by_name['action'].fields.append(
  _ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['candidateRegister'])
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['candidateRegister'].containing_oneof = _ESTIMATEACTIONGASCONSUMPTIONREQUEST.oneofs_by_name['action']
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.oneofs_by_name['action'].fields.append(
  _ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['candidateUpdate'])
_ESTIMATEACTIONGASCONSUMPTIONREQUEST.fields_by_name['candidateUpdate'].containing_oneof = _ESTIMATEACTIONGASCONSUMPTIONREQUEST.oneofs_by_name['action']
_READSTATERESPONSE.fields_by_name['blockIdentifier'].message_type = proto_dot_types_dot_blockchain__pb2._BLOCKIDENTIFIER
_GETEPOCHMETARESPONSE.fields_by_name['epochData'].message_type = proto_dot_types_dot_blockchain__pb2._EPOCHDATA
_GETEPOCHMETARESPONSE.fields_by_name['blockProducersInfo'].message_type = _BLOCKPRODUCERINFO
_GETRAWBLOCKSRESPONSE.fields_by_name['blocks'].message_type = _BLOCKINFO
_LOGSFILTER.fields_by_name['topics'].message_type = _TOPICS
_GETLOGSREQUEST.fields_by_name['filter'].message_type = _LOGSFILTER
_GETLOGSREQUEST.fields_by_name['byBlock'].message_type = _GETLOGSBYBLOCK
_GETLOGSREQUEST.fields_by_name['byRange'].message_type = _GETLOGSBYRANGE
_GETLOGSREQUEST.oneofs_by_name['lookup'].fields.append(
  _GETLOGSREQUEST.fields_by_name['byBlock'])
_GETLOGSREQUEST.fields_by_name['byBlock'].containing_oneof = _GETLOGSREQUEST.oneofs_by_name['lookup']
_GETLOGSREQUEST.oneofs_by_name['lookup'].fields.append(
  _GETLOGSREQUEST.fields_by_name['byRange'])
_GETLOGSREQUEST.fields_by_name['byRange'].containing_oneof = _GETLOGSREQUEST.oneofs_by_name['lookup']
_GETLOGSRESPONSE.fields_by_name['logs'].message_type = proto_dot_types_dot_action__pb2._LOG
_GETEVMTRANSFERSBYACTIONHASHRESPONSE.fields_by_name['actionEvmTransfers'].message_type = proto_dot_types_dot_action__pb2._ACTIONEVMTRANSFER
_GETEVMTRANSFERSBYBLOCKHEIGHTRESPONSE.fields_by_name['blockEvmTransfers'].message_type = proto_dot_types_dot_action__pb2._BLOCKEVMTRANSFER
_GETTRANSACTIONLOGBYACTIONHASHRESPONSE.fields_by_name['transactionLog'].message_type = proto_dot_types_dot_transaction__log__pb2._TRANSACTIONLOG
_GETTRANSACTIONLOGBYBLOCKHEIGHTRESPONSE.fields_by_name['transactionLogs'].message_type = proto_dot_types_dot_transaction__log__pb2._TRANSACTIONLOGS
_GETTRANSACTIONLOGBYBLOCKHEIGHTRESPONSE.fields_by_name['blockIdentifier'].message_type = proto_dot_types_dot_blockchain__pb2._BLOCKIDENTIFIER
_STREAMBLOCKSRESPONSE.fields_by_name['block'].message_type = _BLOCKINFO
_STREAMLOGSREQUEST.fields_by_name['filter'].message_type = _LOGSFILTER
_STREAMLOGSRESPONSE.fields_by_name['log'].message_type = proto_dot_types_dot_action__pb2._LOG
_GETELECTIONBUCKETSRESPONSE.fields_by_name['buckets'].message_type = proto_dot_types_dot_election__pb2._ELECTIONBUCKET
DESCRIPTOR.message_types_by_name['Bucket'] = _BUCKET
DESCRIPTOR.message_types_by_name['GetAccountRequest'] = _GETACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['GetAccountResponse'] = _GETACCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['GetActionsRequest'] = _GETACTIONSREQUEST
DESCRIPTOR.message_types_by_name['GetActionsByIndexRequest'] = _GETACTIONSBYINDEXREQUEST
DESCRIPTOR.message_types_by_name['GetActionByHashRequest'] = _GETACTIONBYHASHREQUEST
DESCRIPTOR.message_types_by_name['GetActionsByAddressRequest'] = _GETACTIONSBYADDRESSREQUEST
DESCRIPTOR.message_types_by_name['GetUnconfirmedActionsByAddressRequest'] = _GETUNCONFIRMEDACTIONSBYADDRESSREQUEST
DESCRIPTOR.message_types_by_name['GetActionsByBlockRequest'] = _GETACTIONSBYBLOCKREQUEST
DESCRIPTOR.message_types_by_name['ActionInfo'] = _ACTIONINFO
DESCRIPTOR.message_types_by_name['ReceiptInfo'] = _RECEIPTINFO
DESCRIPTOR.message_types_by_name['BlockProducerInfo'] = _BLOCKPRODUCERINFO
DESCRIPTOR.message_types_by_name['BlockInfo'] = _BLOCKINFO
DESCRIPTOR.message_types_by_name['GetActionsResponse'] = _GETACTIONSRESPONSE
DESCRIPTOR.message_types_by_name['GetBlockMetasRequest'] = _GETBLOCKMETASREQUEST
DESCRIPTOR.message_types_by_name['GetBlockMetasByIndexRequest'] = _GETBLOCKMETASBYINDEXREQUEST
DESCRIPTOR.message_types_by_name['GetBlockMetaByHashRequest'] = _GETBLOCKMETABYHASHREQUEST
DESCRIPTOR.message_types_by_name['GetBlockMetasResponse'] = _GETBLOCKMETASRESPONSE
DESCRIPTOR.message_types_by_name['GetChainMetaRequest'] = _GETCHAINMETAREQUEST
DESCRIPTOR.message_types_by_name['GetChainMetaResponse'] = _GETCHAINMETARESPONSE
DESCRIPTOR.message_types_by_name['GetServerMetaRequest'] = _GETSERVERMETAREQUEST
DESCRIPTOR.message_types_by_name['GetServerMetaResponse'] = _GETSERVERMETARESPONSE
DESCRIPTOR.message_types_by_name['SendActionRequest'] = _SENDACTIONREQUEST
DESCRIPTOR.message_types_by_name['SendSignedActionBytesRequest'] = _SENDSIGNEDACTIONBYTESREQUEST
DESCRIPTOR.message_types_by_name['SendActionResponse'] = _SENDACTIONRESPONSE
DESCRIPTOR.message_types_by_name['GetReceiptByActionRequest'] = _GETRECEIPTBYACTIONREQUEST
DESCRIPTOR.message_types_by_name['GetReceiptByActionResponse'] = _GETRECEIPTBYACTIONRESPONSE
DESCRIPTOR.message_types_by_name['ReadContractRequest'] = _READCONTRACTREQUEST
DESCRIPTOR.message_types_by_name['ReadContractResponse'] = _READCONTRACTRESPONSE
DESCRIPTOR.message_types_by_name['SuggestGasPriceRequest'] = _SUGGESTGASPRICEREQUEST
DESCRIPTOR.message_types_by_name['SuggestGasPriceResponse'] = _SUGGESTGASPRICERESPONSE
DESCRIPTOR.message_types_by_name['EstimateGasForActionRequest'] = _ESTIMATEGASFORACTIONREQUEST
DESCRIPTOR.message_types_by_name['EstimateActionGasConsumptionRequest'] = _ESTIMATEACTIONGASCONSUMPTIONREQUEST
DESCRIPTOR.message_types_by_name['EstimateActionGasConsumptionResponse'] = _ESTIMATEACTIONGASCONSUMPTIONRESPONSE
DESCRIPTOR.message_types_by_name['EstimateGasForActionResponse'] = _ESTIMATEGASFORACTIONRESPONSE
DESCRIPTOR.message_types_by_name['ReadStateRequest'] = _READSTATEREQUEST
DESCRIPTOR.message_types_by_name['ReadStateResponse'] = _READSTATERESPONSE
DESCRIPTOR.message_types_by_name['GetEpochMetaRequest'] = _GETEPOCHMETAREQUEST
DESCRIPTOR.message_types_by_name['GetEpochMetaResponse'] = _GETEPOCHMETARESPONSE
DESCRIPTOR.message_types_by_name['GetRawBlocksRequest'] = _GETRAWBLOCKSREQUEST
DESCRIPTOR.message_types_by_name['GetRawBlocksResponse'] = _GETRAWBLOCKSRESPONSE
DESCRIPTOR.message_types_by_name['GetLogsByBlock'] = _GETLOGSBYBLOCK
DESCRIPTOR.message_types_by_name['GetLogsByRange'] = _GETLOGSBYRANGE
DESCRIPTOR.message_types_by_name['Topics'] = _TOPICS
DESCRIPTOR.message_types_by_name['LogsFilter'] = _LOGSFILTER
DESCRIPTOR.message_types_by_name['GetLogsRequest'] = _GETLOGSREQUEST
DESCRIPTOR.message_types_by_name['GetLogsResponse'] = _GETLOGSRESPONSE
DESCRIPTOR.message_types_by_name['GetEvmTransfersByActionHashRequest'] = _GETEVMTRANSFERSBYACTIONHASHREQUEST
DESCRIPTOR.message_types_by_name['GetEvmTransfersByActionHashResponse'] = _GETEVMTRANSFERSBYACTIONHASHRESPONSE
DESCRIPTOR.message_types_by_name['GetEvmTransfersByBlockHeightRequest'] = _GETEVMTRANSFERSBYBLOCKHEIGHTREQUEST
DESCRIPTOR.message_types_by_name['GetEvmTransfersByBlockHeightResponse'] = _GETEVMTRANSFERSBYBLOCKHEIGHTRESPONSE
DESCRIPTOR.message_types_by_name['GetTransactionLogByActionHashRequest'] = _GETTRANSACTIONLOGBYACTIONHASHREQUEST
DESCRIPTOR.message_types_by_name['GetTransactionLogByActionHashResponse'] = _GETTRANSACTIONLOGBYACTIONHASHRESPONSE
DESCRIPTOR.message_types_by_name['GetTransactionLogByBlockHeightRequest'] = _GETTRANSACTIONLOGBYBLOCKHEIGHTREQUEST
DESCRIPTOR.message_types_by_name['GetTransactionLogByBlockHeightResponse'] = _GETTRANSACTIONLOGBYBLOCKHEIGHTRESPONSE
DESCRIPTOR.message_types_by_name['StreamBlocksRequest'] = _STREAMBLOCKSREQUEST
DESCRIPTOR.message_types_by_name['StreamBlocksResponse'] = _STREAMBLOCKSRESPONSE
DESCRIPTOR.message_types_by_name['StreamLogsRequest'] = _STREAMLOGSREQUEST
DESCRIPTOR.message_types_by_name['StreamLogsResponse'] = _STREAMLOGSRESPONSE
DESCRIPTOR.message_types_by_name['GetElectionBucketsRequest'] = _GETELECTIONBUCKETSREQUEST
DESCRIPTOR.message_types_by_name['GetElectionBucketsResponse'] = _GETELECTIONBUCKETSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Bucket = _reflection.GeneratedProtocolMessageType('Bucket', (_message.Message,), {
  'DESCRIPTOR' : _BUCKET,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.Bucket)
  })
_sym_db.RegisterMessage(Bucket)

GetAccountRequest = _reflection.GeneratedProtocolMessageType('GetAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetAccountRequest)
  })
_sym_db.RegisterMessage(GetAccountRequest)

GetAccountResponse = _reflection.GeneratedProtocolMessageType('GetAccountResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTRESPONSE,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetAccountResponse)
  })
_sym_db.RegisterMessage(GetAccountResponse)

GetActionsRequest = _reflection.GeneratedProtocolMessageType('GetActionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACTIONSREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetActionsRequest)
  })
_sym_db.RegisterMessage(GetActionsRequest)

GetActionsByIndexRequest = _reflection.GeneratedProtocolMessageType('GetActionsByIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACTIONSBYINDEXREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetActionsByIndexRequest)
  })
_sym_db.RegisterMessage(GetActionsByIndexRequest)

GetActionByHashRequest = _reflection.GeneratedProtocolMessageType('GetActionByHashRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACTIONBYHASHREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetActionByHashRequest)
  })
_sym_db.RegisterMessage(GetActionByHashRequest)

GetActionsByAddressRequest = _reflection.GeneratedProtocolMessageType('GetActionsByAddressRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACTIONSBYADDRESSREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetActionsByAddressRequest)
  })
_sym_db.RegisterMessage(GetActionsByAddressRequest)

GetUnconfirmedActionsByAddressRequest = _reflection.GeneratedProtocolMessageType('GetUnconfirmedActionsByAddressRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUNCONFIRMEDACTIONSBYADDRESSREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetUnconfirmedActionsByAddressRequest)
  })
_sym_db.RegisterMessage(GetUnconfirmedActionsByAddressRequest)

GetActionsByBlockRequest = _reflection.GeneratedProtocolMessageType('GetActionsByBlockRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACTIONSBYBLOCKREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetActionsByBlockRequest)
  })
_sym_db.RegisterMessage(GetActionsByBlockRequest)

ActionInfo = _reflection.GeneratedProtocolMessageType('ActionInfo', (_message.Message,), {
  'DESCRIPTOR' : _ACTIONINFO,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.ActionInfo)
  })
_sym_db.RegisterMessage(ActionInfo)

ReceiptInfo = _reflection.GeneratedProtocolMessageType('ReceiptInfo', (_message.Message,), {
  'DESCRIPTOR' : _RECEIPTINFO,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.ReceiptInfo)
  })
_sym_db.RegisterMessage(ReceiptInfo)

BlockProducerInfo = _reflection.GeneratedProtocolMessageType('BlockProducerInfo', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKPRODUCERINFO,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.BlockProducerInfo)
  })
_sym_db.RegisterMessage(BlockProducerInfo)

BlockInfo = _reflection.GeneratedProtocolMessageType('BlockInfo', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKINFO,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.BlockInfo)
  })
_sym_db.RegisterMessage(BlockInfo)

GetActionsResponse = _reflection.GeneratedProtocolMessageType('GetActionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACTIONSRESPONSE,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetActionsResponse)
  })
_sym_db.RegisterMessage(GetActionsResponse)

GetBlockMetasRequest = _reflection.GeneratedProtocolMessageType('GetBlockMetasRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKMETASREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetBlockMetasRequest)
  })
_sym_db.RegisterMessage(GetBlockMetasRequest)

GetBlockMetasByIndexRequest = _reflection.GeneratedProtocolMessageType('GetBlockMetasByIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKMETASBYINDEXREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetBlockMetasByIndexRequest)
  })
_sym_db.RegisterMessage(GetBlockMetasByIndexRequest)

GetBlockMetaByHashRequest = _reflection.GeneratedProtocolMessageType('GetBlockMetaByHashRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKMETABYHASHREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetBlockMetaByHashRequest)
  })
_sym_db.RegisterMessage(GetBlockMetaByHashRequest)

GetBlockMetasResponse = _reflection.GeneratedProtocolMessageType('GetBlockMetasResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKMETASRESPONSE,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetBlockMetasResponse)
  })
_sym_db.RegisterMessage(GetBlockMetasResponse)

GetChainMetaRequest = _reflection.GeneratedProtocolMessageType('GetChainMetaRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCHAINMETAREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetChainMetaRequest)
  })
_sym_db.RegisterMessage(GetChainMetaRequest)

GetChainMetaResponse = _reflection.GeneratedProtocolMessageType('GetChainMetaResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCHAINMETARESPONSE,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetChainMetaResponse)
  })
_sym_db.RegisterMessage(GetChainMetaResponse)

GetServerMetaRequest = _reflection.GeneratedProtocolMessageType('GetServerMetaRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVERMETAREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetServerMetaRequest)
  })
_sym_db.RegisterMessage(GetServerMetaRequest)

GetServerMetaResponse = _reflection.GeneratedProtocolMessageType('GetServerMetaResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVERMETARESPONSE,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetServerMetaResponse)
  })
_sym_db.RegisterMessage(GetServerMetaResponse)

SendActionRequest = _reflection.GeneratedProtocolMessageType('SendActionRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDACTIONREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.SendActionRequest)
  })
_sym_db.RegisterMessage(SendActionRequest)

SendSignedActionBytesRequest = _reflection.GeneratedProtocolMessageType('SendSignedActionBytesRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDSIGNEDACTIONBYTESREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.SendSignedActionBytesRequest)
  })
_sym_db.RegisterMessage(SendSignedActionBytesRequest)

SendActionResponse = _reflection.GeneratedProtocolMessageType('SendActionResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDACTIONRESPONSE,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.SendActionResponse)
  })
_sym_db.RegisterMessage(SendActionResponse)

GetReceiptByActionRequest = _reflection.GeneratedProtocolMessageType('GetReceiptByActionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRECEIPTBYACTIONREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetReceiptByActionRequest)
  })
_sym_db.RegisterMessage(GetReceiptByActionRequest)

GetReceiptByActionResponse = _reflection.GeneratedProtocolMessageType('GetReceiptByActionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRECEIPTBYACTIONRESPONSE,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetReceiptByActionResponse)
  })
_sym_db.RegisterMessage(GetReceiptByActionResponse)

ReadContractRequest = _reflection.GeneratedProtocolMessageType('ReadContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _READCONTRACTREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.ReadContractRequest)
  })
_sym_db.RegisterMessage(ReadContractRequest)

ReadContractResponse = _reflection.GeneratedProtocolMessageType('ReadContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _READCONTRACTRESPONSE,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.ReadContractResponse)
  })
_sym_db.RegisterMessage(ReadContractResponse)

SuggestGasPriceRequest = _reflection.GeneratedProtocolMessageType('SuggestGasPriceRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUGGESTGASPRICEREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.SuggestGasPriceRequest)
  })
_sym_db.RegisterMessage(SuggestGasPriceRequest)

SuggestGasPriceResponse = _reflection.GeneratedProtocolMessageType('SuggestGasPriceResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUGGESTGASPRICERESPONSE,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.SuggestGasPriceResponse)
  })
_sym_db.RegisterMessage(SuggestGasPriceResponse)

EstimateGasForActionRequest = _reflection.GeneratedProtocolMessageType('EstimateGasForActionRequest', (_message.Message,), {
  'DESCRIPTOR' : _ESTIMATEGASFORACTIONREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.EstimateGasForActionRequest)
  })
_sym_db.RegisterMessage(EstimateGasForActionRequest)

EstimateActionGasConsumptionRequest = _reflection.GeneratedProtocolMessageType('EstimateActionGasConsumptionRequest', (_message.Message,), {
  'DESCRIPTOR' : _ESTIMATEACTIONGASCONSUMPTIONREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.EstimateActionGasConsumptionRequest)
  })
_sym_db.RegisterMessage(EstimateActionGasConsumptionRequest)

EstimateActionGasConsumptionResponse = _reflection.GeneratedProtocolMessageType('EstimateActionGasConsumptionResponse', (_message.Message,), {
  'DESCRIPTOR' : _ESTIMATEACTIONGASCONSUMPTIONRESPONSE,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.EstimateActionGasConsumptionResponse)
  })
_sym_db.RegisterMessage(EstimateActionGasConsumptionResponse)

EstimateGasForActionResponse = _reflection.GeneratedProtocolMessageType('EstimateGasForActionResponse', (_message.Message,), {
  'DESCRIPTOR' : _ESTIMATEGASFORACTIONRESPONSE,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.EstimateGasForActionResponse)
  })
_sym_db.RegisterMessage(EstimateGasForActionResponse)

ReadStateRequest = _reflection.GeneratedProtocolMessageType('ReadStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _READSTATEREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.ReadStateRequest)
  })
_sym_db.RegisterMessage(ReadStateRequest)

ReadStateResponse = _reflection.GeneratedProtocolMessageType('ReadStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _READSTATERESPONSE,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.ReadStateResponse)
  })
_sym_db.RegisterMessage(ReadStateResponse)

GetEpochMetaRequest = _reflection.GeneratedProtocolMessageType('GetEpochMetaRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEPOCHMETAREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetEpochMetaRequest)
  })
_sym_db.RegisterMessage(GetEpochMetaRequest)

GetEpochMetaResponse = _reflection.GeneratedProtocolMessageType('GetEpochMetaResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETEPOCHMETARESPONSE,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetEpochMetaResponse)
  })
_sym_db.RegisterMessage(GetEpochMetaResponse)

GetRawBlocksRequest = _reflection.GeneratedProtocolMessageType('GetRawBlocksRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRAWBLOCKSREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetRawBlocksRequest)
  })
_sym_db.RegisterMessage(GetRawBlocksRequest)

GetRawBlocksResponse = _reflection.GeneratedProtocolMessageType('GetRawBlocksResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRAWBLOCKSRESPONSE,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetRawBlocksResponse)
  })
_sym_db.RegisterMessage(GetRawBlocksResponse)

GetLogsByBlock = _reflection.GeneratedProtocolMessageType('GetLogsByBlock', (_message.Message,), {
  'DESCRIPTOR' : _GETLOGSBYBLOCK,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetLogsByBlock)
  })
_sym_db.RegisterMessage(GetLogsByBlock)

GetLogsByRange = _reflection.GeneratedProtocolMessageType('GetLogsByRange', (_message.Message,), {
  'DESCRIPTOR' : _GETLOGSBYRANGE,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetLogsByRange)
  })
_sym_db.RegisterMessage(GetLogsByRange)

Topics = _reflection.GeneratedProtocolMessageType('Topics', (_message.Message,), {
  'DESCRIPTOR' : _TOPICS,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.Topics)
  })
_sym_db.RegisterMessage(Topics)

LogsFilter = _reflection.GeneratedProtocolMessageType('LogsFilter', (_message.Message,), {
  'DESCRIPTOR' : _LOGSFILTER,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.LogsFilter)
  })
_sym_db.RegisterMessage(LogsFilter)

GetLogsRequest = _reflection.GeneratedProtocolMessageType('GetLogsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLOGSREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetLogsRequest)
  })
_sym_db.RegisterMessage(GetLogsRequest)

GetLogsResponse = _reflection.GeneratedProtocolMessageType('GetLogsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLOGSRESPONSE,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetLogsResponse)
  })
_sym_db.RegisterMessage(GetLogsResponse)

GetEvmTransfersByActionHashRequest = _reflection.GeneratedProtocolMessageType('GetEvmTransfersByActionHashRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEVMTRANSFERSBYACTIONHASHREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetEvmTransfersByActionHashRequest)
  })
_sym_db.RegisterMessage(GetEvmTransfersByActionHashRequest)

GetEvmTransfersByActionHashResponse = _reflection.GeneratedProtocolMessageType('GetEvmTransfersByActionHashResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETEVMTRANSFERSBYACTIONHASHRESPONSE,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetEvmTransfersByActionHashResponse)
  })
_sym_db.RegisterMessage(GetEvmTransfersByActionHashResponse)

GetEvmTransfersByBlockHeightRequest = _reflection.GeneratedProtocolMessageType('GetEvmTransfersByBlockHeightRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEVMTRANSFERSBYBLOCKHEIGHTREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetEvmTransfersByBlockHeightRequest)
  })
_sym_db.RegisterMessage(GetEvmTransfersByBlockHeightRequest)

GetEvmTransfersByBlockHeightResponse = _reflection.GeneratedProtocolMessageType('GetEvmTransfersByBlockHeightResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETEVMTRANSFERSBYBLOCKHEIGHTRESPONSE,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetEvmTransfersByBlockHeightResponse)
  })
_sym_db.RegisterMessage(GetEvmTransfersByBlockHeightResponse)

GetTransactionLogByActionHashRequest = _reflection.GeneratedProtocolMessageType('GetTransactionLogByActionHashRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTRANSACTIONLOGBYACTIONHASHREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetTransactionLogByActionHashRequest)
  })
_sym_db.RegisterMessage(GetTransactionLogByActionHashRequest)

GetTransactionLogByActionHashResponse = _reflection.GeneratedProtocolMessageType('GetTransactionLogByActionHashResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTRANSACTIONLOGBYACTIONHASHRESPONSE,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetTransactionLogByActionHashResponse)
  })
_sym_db.RegisterMessage(GetTransactionLogByActionHashResponse)

GetTransactionLogByBlockHeightRequest = _reflection.GeneratedProtocolMessageType('GetTransactionLogByBlockHeightRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTRANSACTIONLOGBYBLOCKHEIGHTREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetTransactionLogByBlockHeightRequest)
  })
_sym_db.RegisterMessage(GetTransactionLogByBlockHeightRequest)

GetTransactionLogByBlockHeightResponse = _reflection.GeneratedProtocolMessageType('GetTransactionLogByBlockHeightResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTRANSACTIONLOGBYBLOCKHEIGHTRESPONSE,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetTransactionLogByBlockHeightResponse)
  })
_sym_db.RegisterMessage(GetTransactionLogByBlockHeightResponse)

StreamBlocksRequest = _reflection.GeneratedProtocolMessageType('StreamBlocksRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMBLOCKSREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.StreamBlocksRequest)
  })
_sym_db.RegisterMessage(StreamBlocksRequest)

StreamBlocksResponse = _reflection.GeneratedProtocolMessageType('StreamBlocksResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMBLOCKSRESPONSE,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.StreamBlocksResponse)
  })
_sym_db.RegisterMessage(StreamBlocksResponse)

StreamLogsRequest = _reflection.GeneratedProtocolMessageType('StreamLogsRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMLOGSREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.StreamLogsRequest)
  })
_sym_db.RegisterMessage(StreamLogsRequest)

StreamLogsResponse = _reflection.GeneratedProtocolMessageType('StreamLogsResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMLOGSRESPONSE,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.StreamLogsResponse)
  })
_sym_db.RegisterMessage(StreamLogsResponse)

GetElectionBucketsRequest = _reflection.GeneratedProtocolMessageType('GetElectionBucketsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETELECTIONBUCKETSREQUEST,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetElectionBucketsRequest)
  })
_sym_db.RegisterMessage(GetElectionBucketsRequest)

GetElectionBucketsResponse = _reflection.GeneratedProtocolMessageType('GetElectionBucketsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETELECTIONBUCKETSRESPONSE,
  '__module__' : 'proto.api.api_pb2'
  # @@protoc_insertion_point(class_scope:iotexapi.GetElectionBucketsResponse)
  })
_sym_db.RegisterMessage(GetElectionBucketsResponse)


DESCRIPTOR._options = None

_APISERVICE = _descriptor.ServiceDescriptor(
  name='APIService',
  full_name='iotexapi.APIService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=5423,
  serialized_end=7496,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetAccount',
    full_name='iotexapi.APIService.GetAccount',
    index=0,
    containing_service=None,
    input_type=_GETACCOUNTREQUEST,
    output_type=_GETACCOUNTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetActions',
    full_name='iotexapi.APIService.GetActions',
    index=1,
    containing_service=None,
    input_type=_GETACTIONSREQUEST,
    output_type=_GETACTIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBlockMetas',
    full_name='iotexapi.APIService.GetBlockMetas',
    index=2,
    containing_service=None,
    input_type=_GETBLOCKMETASREQUEST,
    output_type=_GETBLOCKMETASRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetChainMeta',
    full_name='iotexapi.APIService.GetChainMeta',
    index=3,
    containing_service=None,
    input_type=_GETCHAINMETAREQUEST,
    output_type=_GETCHAINMETARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetServerMeta',
    full_name='iotexapi.APIService.GetServerMeta',
    index=4,
    containing_service=None,
    input_type=_GETSERVERMETAREQUEST,
    output_type=_GETSERVERMETARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendAction',
    full_name='iotexapi.APIService.SendAction',
    index=5,
    containing_service=None,
    input_type=_SENDACTIONREQUEST,
    output_type=_SENDACTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetReceiptByAction',
    full_name='iotexapi.APIService.GetReceiptByAction',
    index=6,
    containing_service=None,
    input_type=_GETRECEIPTBYACTIONREQUEST,
    output_type=_GETRECEIPTBYACTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReadContract',
    full_name='iotexapi.APIService.ReadContract',
    index=7,
    containing_service=None,
    input_type=_READCONTRACTREQUEST,
    output_type=_READCONTRACTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SuggestGasPrice',
    full_name='iotexapi.APIService.SuggestGasPrice',
    index=8,
    containing_service=None,
    input_type=_SUGGESTGASPRICEREQUEST,
    output_type=_SUGGESTGASPRICERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EstimateGasForAction',
    full_name='iotexapi.APIService.EstimateGasForAction',
    index=9,
    containing_service=None,
    input_type=_ESTIMATEGASFORACTIONREQUEST,
    output_type=_ESTIMATEGASFORACTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EstimateActionGasConsumption',
    full_name='iotexapi.APIService.EstimateActionGasConsumption',
    index=10,
    containing_service=None,
    input_type=_ESTIMATEACTIONGASCONSUMPTIONREQUEST,
    output_type=_ESTIMATEACTIONGASCONSUMPTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReadState',
    full_name='iotexapi.APIService.ReadState',
    index=11,
    containing_service=None,
    input_type=_READSTATEREQUEST,
    output_type=_READSTATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEpochMeta',
    full_name='iotexapi.APIService.GetEpochMeta',
    index=12,
    containing_service=None,
    input_type=_GETEPOCHMETAREQUEST,
    output_type=_GETEPOCHMETARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRawBlocks',
    full_name='iotexapi.APIService.GetRawBlocks',
    index=13,
    containing_service=None,
    input_type=_GETRAWBLOCKSREQUEST,
    output_type=_GETRAWBLOCKSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLogs',
    full_name='iotexapi.APIService.GetLogs',
    index=14,
    containing_service=None,
    input_type=_GETLOGSREQUEST,
    output_type=_GETLOGSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEvmTransfersByActionHash',
    full_name='iotexapi.APIService.GetEvmTransfersByActionHash',
    index=15,
    containing_service=None,
    input_type=_GETEVMTRANSFERSBYACTIONHASHREQUEST,
    output_type=_GETEVMTRANSFERSBYACTIONHASHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEvmTransfersByBlockHeight',
    full_name='iotexapi.APIService.GetEvmTransfersByBlockHeight',
    index=16,
    containing_service=None,
    input_type=_GETEVMTRANSFERSBYBLOCKHEIGHTREQUEST,
    output_type=_GETEVMTRANSFERSBYBLOCKHEIGHTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTransactionLogByActionHash',
    full_name='iotexapi.APIService.GetTransactionLogByActionHash',
    index=17,
    containing_service=None,
    input_type=_GETTRANSACTIONLOGBYACTIONHASHREQUEST,
    output_type=_GETTRANSACTIONLOGBYACTIONHASHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTransactionLogByBlockHeight',
    full_name='iotexapi.APIService.GetTransactionLogByBlockHeight',
    index=18,
    containing_service=None,
    input_type=_GETTRANSACTIONLOGBYBLOCKHEIGHTREQUEST,
    output_type=_GETTRANSACTIONLOGBYBLOCKHEIGHTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamBlocks',
    full_name='iotexapi.APIService.StreamBlocks',
    index=19,
    containing_service=None,
    input_type=_STREAMBLOCKSREQUEST,
    output_type=_STREAMBLOCKSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamLogs',
    full_name='iotexapi.APIService.StreamLogs',
    index=20,
    containing_service=None,
    input_type=_STREAMLOGSREQUEST,
    output_type=_STREAMLOGSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetElectionBuckets',
    full_name='iotexapi.APIService.GetElectionBuckets',
    index=21,
    containing_service=None,
    input_type=_GETELECTIONBUCKETSREQUEST,
    output_type=_GETELECTIONBUCKETSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_APISERVICE)

DESCRIPTOR.services_by_name['APIService'] = _APISERVICE


_TRANSACTIONLOGSERVICE = _descriptor.ServiceDescriptor(
  name='TransactionLogService',
  full_name='iotexapi.TransactionLogService',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=7499,
  serialized_end=7791,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetTransactionLogByActionHash',
    full_name='iotexapi.TransactionLogService.GetTransactionLogByActionHash',
    index=0,
    containing_service=None,
    input_type=_GETTRANSACTIONLOGBYACTIONHASHREQUEST,
    output_type=_GETTRANSACTIONLOGBYACTIONHASHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTransactionLogByBlockHeight',
    full_name='iotexapi.TransactionLogService.GetTransactionLogByBlockHeight',
    index=1,
    containing_service=None,
    input_type=_GETTRANSACTIONLOGBYBLOCKHEIGHTREQUEST,
    output_type=_GETTRANSACTIONLOGBYBLOCKHEIGHTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRANSACTIONLOGSERVICE)

DESCRIPTOR.services_by_name['TransactionLogService'] = _TRANSACTIONLOGSERVICE

# @@protoc_insertion_point(module_scope)
